@@ -105,6 +105,13 @@ class GitlabRepository(Repository):
         return False
 
     def has_successful_pr_build(self, identifier: GitlabMergeRequest) -> bool:
+        if (
+            identifier.approvals.get().attributes.get("merge_status", "")
+            != "can_be_merged"
+        ):
+            log.debug("Approvals missing", repo=str(self), id=identifier.get_id())
+            return False
+
         failed = False
         for commit_status in self._project.commits.get(
             id=identifier.sha, lazy=True
@@ -148,7 +155,7 @@ class GitlabRepository(Repository):
         return self._project.path
 
     def pr_created_at(self, pr: GitlabMergeRequest) -> datetime.datetime:
-        corrected = pr.created_at.replace("Z", "+00:00")
+        corrected: str = pr.created_at.replace("Z", "")
         return datetime.datetime.fromisoformat(corrected)
 
     @property
